/* $Workfile: OtxBurstD.h $   $Revision: 16 $    $Modtime: 4/28/08 8:20p $  */

#ifndef OTX_BURST_DEF_H
#define OTX_BURST_DEF_H
/*******************************************************************************

  @doc PublicHwApi OtxBurstD

  Copyright (C) 2003-2008 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxBurstD | Constants, Macros, and Types for the DMA Burst Device Management Functions

  @contents2
  OtxBurstD.h |

  @index const enum struct type | OtxBurstD

  @contents2
  OTX DMA Burst Device Macros, Constants, and Types |

  @head3 Enumerated Types  |

  @index enum | OtxBriD

  @head3 Struct Types |

  @index struct | OtxBriD

  @head3 Constants |

  @index const | OtxBriD

  @head3 Other Types |

  @index type | OtxBriD

*******************************************************************************/

#include "OtxType.h"    // OTX specific type definitions

#include "OtxErr.h"

#ifdef __cplusplus
extern "C" {
#endif


/******************************************************************************
  @enum 
    DSP Device Attributes
******************************************************************************/
enum OtxBurstDeviceAttributesE {
  OTX_ATTR_BURST_TRIGGER                  = OTX_ATTR_END + 1,   // @emem (OTX_ATTRIB_UINT32) Read/Write. DMA transfer signal trigger value (1,2,4,8,16,32).
  OTX_ATTR_BURST_TX_BUFFER_SIZE           = OTX_ATTR_END + 2,   // @emem (OTX_ATTRIB_UINT32) Read only. DMA Send buffer size.
  OTX_ATTR_BURST_MAX_TIMESLOTS            = OTX_ATTR_END + 3,   // @emem (OTX_ATTRIB_UINT32) Read only. DMA Buffer max timeslots per transfer.
  OTX_ATTR_BURST_STAT_RECV_STARTS         = OTX_ATTR_END + 4,   // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv actual dma transfers initiated.
  OTX_ATTR_BURST_STAT_RECV_COMPLETES      = OTX_ATTR_END + 5,   // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv actual dma transfers completed.
  OTX_ATTR_BURST_STAT_RECV_PARTIAL        = OTX_ATTR_END + 6,   // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv partial transfer due to framemask.
  OTX_ATTR_BURST_STAT_RECV_FULL           = OTX_ATTR_END + 7,   // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv count of max dma size transfers.
  OTX_ATTR_BURST_STAT_RECV_ABORTS         = OTX_ATTR_END + 8,   // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv actual dma transfers aborts.
  OTX_ATTR_BURST_STAT_RECV_AMOUNT         = OTX_ATTR_END + 9,   // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv amount of data transfered.
  OTX_ATTR_BURST_STAT_RECV_ERRORS         = OTX_ATTR_END + 10,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv count of processing errors.
  OTX_ATTR_BURST_STAT_RECV_OURUNS         = OTX_ATTR_END + 11,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv amount of over runs.
  OTX_ATTR_BURST_STAT_RECV_OURUNS_USER    = OTX_ATTR_END + 12,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send amount of over runs caused by the user app not reading the data in a timely manner.
  OTX_ATTR_BURST_STAT_RECV_DMABUSY        = OTX_ATTR_END + 13,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv count of DMA busy occurances.
  OTX_ATTR_BURST_STAT_RECV_NOTIFY         = OTX_ATTR_END + 14,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv logical device notifies.
  OTX_ATTR_BURST_STAT_RECV_NOTIFY_PARTIAL = OTX_ATTR_END + 15,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Recv logical device notifies - partial.
  OTX_ATTR_BURST_STAT_SEND_STARTS         = OTX_ATTR_END + 16,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send actual dma transfers initiated.
  OTX_ATTR_BURST_STAT_SEND_COMPLETES      = OTX_ATTR_END + 17,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send actual dma transfers completed.
  OTX_ATTR_BURST_STAT_SEND_PARTIAL        = OTX_ATTR_END + 18,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send partial transfer due to framemask.
  OTX_ATTR_BURST_STAT_SEND_FULL           = OTX_ATTR_END + 19,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send count of max dma size transfers.
  OTX_ATTR_BURST_STAT_SEND_ABORTS         = OTX_ATTR_END + 20,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send actual dma transfers aborts.
  OTX_ATTR_BURST_STAT_SEND_AMOUNT         = OTX_ATTR_END + 21,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send amount of data transfered.
  OTX_ATTR_BURST_STAT_SEND_ERRORS         = OTX_ATTR_END + 22,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send count of processing errors.
  OTX_ATTR_BURST_STAT_SEND_OURUNS         = OTX_ATTR_END + 23,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send amount of under runs.
  OTX_ATTR_BURST_STAT_SEND_OURUNS_USER    = OTX_ATTR_END + 24,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send amount of under runs caused by the user app not keeping the data pump primed.
  OTX_ATTR_BURST_STAT_SEND_DMABUSY        = OTX_ATTR_END + 25,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send count of DMA busy occurances.
  OTX_ATTR_BURST_STAT_SEND_NOTIFY         = OTX_ATTR_END + 26,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send logical device notifies.
  OTX_ATTR_BURST_STAT_SEND_NOTIFY_PARTIAL = OTX_ATTR_END + 27,  // @emem (OTX_ATTRIB_UINT32) Read only. Number of Send logical device notifies - partial.
  OTX_ATTR_BURST_GET_FRAME_REF_DATA       = OTX_ATTR_END + 28,  // @emem (OTX_ATTRIB_UINT32) Read only. Fills a OtxBurstFrameRefAndTime with Burst Frame Reference data.
  OTX_ATTR_BURST_RECEIVER_FIFO_SIZE       = OTX_ATTR_END + 29,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Burst Receiver user buffer size. 
  OTX_ATTR_BURST_RECEIVER_FIFO_TRIGGER    = OTX_ATTR_END + 30,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Burst Receiver user buffer trigger level.
  OTX_ATTR_BURST_SENDER_FIFO_SIZE         = OTX_ATTR_END + 31,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Burst Sender user buffer size. 
  OTX_ATTR_BURST_SENDER_FIFO_TRIGGER      = OTX_ATTR_END + 32,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Burst Sender user buffer trigger level.
  OTX_ATTR_BURST_RECEIVER_FIFO_COUNT      = OTX_ATTR_END + 33,  // @emem (OTX_ATTRIB_UINT32) Read Only. Burst Receiver user buffer current level.
  OTX_ATTR_BURST_RECEIVER_FIFO_PEAK       = OTX_ATTR_END + 34,  // @emem (OTX_ATTRIB_UINT32) Read Only. Burst Receiver user buffer peak level.
  OTX_ATTR_BURST_RECEIVER_FIFO_TRIGGER_COUNT = OTX_ATTR_END + 35,  // @emem (OTX_ATTRIB_UINT32) Read Only. Burst Receiver user buffer current trigger count
  OTX_ATTR_BURST_SENDER_FIFO_COUNT        = OTX_ATTR_END + 36,  // @emem (OTX_ATTRIB_UINT32) Read Only. Burst Sender user buffer current level.
  OTX_ATTR_BURST_SENDER_FIFO_PEAK         = OTX_ATTR_END + 37,  // @emem (OTX_ATTRIB_UINT32) Read Only. Burst Sender user buffer peak level.
  OTX_ATTR_BURST_SENDER_FIFO_TRIGGER_COUNT = OTX_ATTR_END + 38,  // @emem (OTX_ATTRIB_UINT32) Read Only. Burst Sender user buffer current trigger count
  OTX_ATTR_BURST_STAT_RECV_CODE_ERRORS    = OTX_ATTR_END + 39,  // @emem (OTX_ATTRIB_UINT32) Read Only. Number of internal errors in the Recv direction. Should always be zero.
  OTX_ATTR_BURST_STAT_RECV_RESERVED0      = OTX_ATTR_END + 40,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_STAT_RECV_RESERVED1      = OTX_ATTR_END + 41,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_STAT_RECV_RESERVED2      = OTX_ATTR_END + 42,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_STAT_RECV_RESERVED3      = OTX_ATTR_END + 43,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_STAT_RECV_RESERVED4      = OTX_ATTR_END + 44,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_STAT_RECV_RESERVED5      = OTX_ATTR_END + 45,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_STAT_RECV_RESERVED6      = OTX_ATTR_END + 46,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_STAT_RECV_RESERVED7      = OTX_ATTR_END + 47,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_STAT_SEND_CODE_ERRORS    = OTX_ATTR_END + 48,  // @emem (OTX_ATTRIB_UINT32) Read Only. Number of internal errors in the Send direction. Should always be zero.
  OTX_ATTR_BURST_STAT_SEND_RESERVED0      = OTX_ATTR_END + 49,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_STAT_SEND_RESERVED1      = OTX_ATTR_END + 50,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_STAT_SEND_RESERVED2      = OTX_ATTR_END + 51,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_STAT_SEND_RESERVED3      = OTX_ATTR_END + 52,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_STAT_SEND_RESERVED4      = OTX_ATTR_END + 53,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_STAT_SEND_RESERVED5      = OTX_ATTR_END + 54,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_STAT_SEND_RESERVED6      = OTX_ATTR_END + 55,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_STAT_SEND_RESERVED7      = OTX_ATTR_END + 56,  // @emem (OTX_ATTRIB_UINT32) Read Only. Reserved for internal use
  OTX_ATTR_BURST_RECV_DISABLED            = OTX_ATTR_END + 57,  // @emem (OTX_ATTRIB_BOOL) Read/Write. Default is OTX_FALSE;
                                                                // <nl> Set this attribute to OTX_TRUE to always keep the DMA Recv 
                                                                // interrupts disabled (masked) in the <f OtxDrvEnable> and <f OtxDrvDisable> calls. 
                                                                // This attribute can be used to increase system performance (reduce the number of
                                                                // interrupts that the system needs to handle) in an application that only uses the
                                                                // Burst device to send data (no reception of data).
                                                                // <nl> Note that this attribute does not return or change the enable/disable state of 
                                                                // the Burst device. A change in this attribute value does not take effect until the
                                                                // <f OtxDrvEnable> and <f OtxDrvDisable> functions are called.
  OTX_ATTR_BURST_SEND_DISABLED            = OTX_ATTR_END + 58,  // @emem (OTX_ATTRIB_BOOL) Read/Write. Default is OTX_FALSE;
                                                                // <nl> Set this attribute to OTX_TRUE to always keep the DMA Send 
                                                                // interrupts disabled (masked) in the <f OtxDrvEnable> and <f OtxDrvDisable> calls. 
                                                                // This attribute can be used to increase system performance (reduce the number of
                                                                // interrupts that the system needs to handle) in an application that only uses the
                                                                // Burst device to receive data (no transmission of data).
                                                                // <nl> Note that this attribute does not return or change the enable/disable state of 
                                                                // the Burst device. A change in this attribute value does not take effect until the
                                                                // <f OtxDrvEnable> and <f OtxDrvDisable> functions are called.
  OTX_ATTR_BURST_DMA_RECEIVE_SIGNAL       = OTX_ATTR_END + 59,  // @emem (OTX_ATTRIB_BOOL) Default is OTX_FALSE; Send a single DMA transfer complete event.
                                                                // <e OtxBurstEventCodesE.OTX_BURST_RECEIVER_DMA_COMPLETE>
  OTX_ATTR_BURST_DMA_SEND_SIGNAL          = OTX_ATTR_END + 60,  // @emem (OTX_ATTRIB_BOOL) Default is OTX_FALSE; Send a single DMA transfer complete event.
                                                                // <e OtxBurstEventCodesE.OTX_BURST_RECEIVER_DMA_COMPLETE>
  OTX_ATTR_BURST_SENDER_GET_FRAME_REF_DATA= OTX_ATTR_END + 61,  // @emem (OTX_ATTRIB_UINT32) Read only. Fills a OtxBurstFrameRefAndTime with Burst Frame Reference data.
  OTX_ATTR_BURST_END                      = OTX_ATTR_END + 62
};

typedef enum OtxBurstDeviceAttributesE OtxBurstDeviceAttributesE;


/******************************************************************************
  @enum
    DSP Event Codes
******************************************************************************/
enum OtxBurstEventCodesE {
  OTX_BURST_EC_BUFFER_OVERRUN             = 0x00,   // @emem Receiver data overrun error - data lost
  OTX_BURST_EC_BUFFER_UNDERRUN            = 0x01,   // @emem Sender data underrun error
  OTX_BURST_RECEIVER_EC_DATA_AVAILABLE    = 0x02,   // @emem Receiver has data available for the user (Receiver trigger level has been hit)
  OTX_BURST_SENDER_EC_BUF_DEPLETED        = 0x03,   // @emem Sender buffer has depleted lower than the trigger level. Now accepting more data.
  OTX_BURST_RECEIVER_DMA_COMPLETE         = 0x04,   // @emem Receiver DMA transfer completed. 
  OTX_BURST_SENDER_DMA_COMPLETE           = 0x05,   // @emem Sender DMA transfer completed.
  OTX_BURST_END_OF_EVENT_CODES
};
typedef enum OtxBurstEventCodesE OtxBurstEventCodesE;

/******************************************************************************
  
  @struct 
    Contains the given Frame Reference Counter, as well as the Frame's System
    Time.  This is used to track the reference time frames from the Burst
    Device.

******************************************************************************/
struct OtxBurstFrameRefAndTime {
  OTX_UINT64    m_FrameCounter;     // @field Frame Reference Counter
  OsaDateTime   m_FrameDateTime;    // @field Absolute time in 100 nanosecond increments since midnight Jan 1, 1601, of the given Frame Counter
};

typedef struct OtxBurstFrameRefAndTime OtxBurstFrameRefAndTime;

#ifdef __cplusplus
}  // extern "C"
#endif


/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2003-2008

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif    // OTX_BURST_DEF_H

                                                                                                                         
